#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pandoc-server
version:              0.1.0.10
visibility:           public
id:                   pandoc-server-0.1.0.10-E3x5AJJoEEE5OieRfLyZp8
key:                  pandoc-server-0.1.0.10-E3x5AJJoEEE5OieRfLyZp8
license:              GPL-2.0-or-later
copyright:            (c) 2006-2024 John MacFarlane
maintainer:           John MacFarlane <jgm@berkeley.edu>
author:               John MacFarlane <jgm@berkeley.edu>
stability:            alpha
homepage:             https://pandoc.org
synopsis:             Pandoc document conversion as an HTTP servant-server
description:
    Pandoc-server provides pandoc'\''s document conversion functions
    in an HTTP server.

category:             Text
abi:                  e59226f29f34514ae6af8e8cc252b2b2
exposed:              True
exposed-modules:      Text.Pandoc.Server
import-dirs:          /usr/lib/ghc-9.6.6/site-local/pandoc-server-0.1.0.10
library-dirs:         /usr/lib/ghc-9.6.6/site-local/pandoc-server-0.1.0.10
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/pandoc-server-0.1.0.10
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pandoc-server
hs-libraries:         HSpandoc-server-0.1.0.10-E3x5AJJoEEE5OieRfLyZp8
depends:
    aeson-2.2.2.0-1j2UQRt1mV1Loqrh8KvmRL base-4.18.2.1
    base64-bytestring-1.2.1.0-1NArAo3cNK0LoUlrXpNy9J
    bytestring-0.11.5.3 containers-0.6.7
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz
    doctemplates-0.11.0.1-FvuEjXUDrpI5mJoD4VUCh
    pandoc-3.6-FosHnOrBTvjBs02zzCXwgV
    pandoc-types-1.23.1-G7QY9CPJSQFhNGtD8Sqsj
    servant-server-0.20.3.0-3l2Bv5vX8SVKvNo3wVC7rX
    skylighting-0.14.4-7VSxYpc3zrrE0QtD6OKHsX text-2.0.2
    unicode-collation-0.1.3.6-G0kSm81DCEnCW1WosxqKmi
    wai-3.2.4-6gB18tSigkFBnxzBP5SLbh
    wai-cors-0.2.7-7pNUnzSb7lKAM4kaMfauoD

haddock-interfaces:
    /usr/share/doc/haskell-pandoc-server/html/pandoc-server.haddock

haddock-html:         /usr/share/doc/haskell-pandoc-server/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

